# Changelog
All changes made in **akademy-matriculation** project will be listed in this file.

The format as follows the recomendations of [Keep a Changelog](https://keepachangelog.com/pt-BR/1.0.0/). And Semantic Versioning


## [1.1.5] - 2026-03-04
### Added
- Added German translation


## [1.1.4] - 2026-02-09
### Changed
- Add company relationship


## [1.1.3] - 2026-02-01
### Changed
- Update to SAGE Edu version 1.2


## [1.1.2] - 2025-01-18
### Changed
- Remove evaluation dependencies


## [1.1.1] - 2025-01-18
### Added
- During registration, candidates can now select their desired institution and proceed with enrollment.


## [1.1.0] - 2026-01-18
### Changed
- Start update to Tryton version 7.0

## [1.0.4] - 2025-01-10
### Added
- Report Default PDF


## [1.0.3] - 2025-01-04
### Added
- Added French translation


## [1.0.2] - 2026-01-02
### Changed
- Repository hosting transferred to primary maintainer’s GitHub account to ensure continued development and releases


## [1.0.1] - 2025-12-29
### Changed
- Update reports

